==> ukui-window-switch_3.1.1.0.orig.tar.gz: ukui-window-switch-3.1.1.0/windowsview/ukui-window-switch_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN" sourcelanguage="en_US">
<context>
    <name>DesktopArea</name>
    <message>
        <source>Desktop</source>
        <translatorcomment>工作区</translatorcomment>
        <translation type="vanished">工作区</translation>
    </message>
    <message>
        <source>New Desktop</source>
        <translatorcomment>新建工作区</translatorcomment>
        <translation type="vanished">新建工作区</translation>
    </message>
</context>
<context>
    <name>MasterDesktopArea</name>
    <message>
        <source>Desktop</source>
        <translatorcomment>工作区</translatorcomment>
        <translation type="vanished">工作区</translation>
    </message>
    <message>
        <source>New Desktop</source>
        <translatorcomment>新建工作区</translatorcomment>
        <translation type="vanished">新建工作区</translation>
    </message>
</context>
<context>
    <name>MasterNewDesktopButton</name>
    <message>
        <location filename="qml/MasterNewDesktopButton.qml" line="106"/>
        <source>New Desktop</source>
        <translation type="unfinished">新建工作区</translation>
    </message>
</context>
<context>
    <name>MasterVirtualDesktopWindow</name>
    <message>
        <location filename="qml/MasterVirtualDesktopWindow.qml" line="70"/>
        <source>Desktop</source>
        <translation type="unfinished">工作区</translation>
    </message>
</context>
<context>
    <name>NewDesktopButton</name>
    <message>
        <location filename="qml/NewDesktopButton.qml" line="109"/>
        <source>New Desktop</source>
        <translatorcomment>新建工作区</translatorcomment>
        <translation>新建工作区</translation>
    </message>
</context>
<context>
    <name>TabletViewClearAllWindowButton</name>
    <message>
        <location filename="qml/TabletViewClearAllWindowButton.qml" line="59"/>
        <source>Clear</source>
        <translatorcomment>清除</translatorcomment>
        <translation>清除</translation>
    </message>
</context>
<context>
    <name>TabletViewRootWindow</name>
    <message>
        <location filename="qml/TabletViewRootWindow.qml" line="146"/>
        <source>No recent tasks</source>
        <translatorcomment>无应用开启</translatorcomment>
        <translation>无应用开启</translation>
    </message>
</context>
<context>
    <name>VirtualDesktopWindow</name>
    <message>
        <location filename="qml/VirtualDesktopWindow.qml" line="73"/>
        <source>Desktop</source>
        <translatorcomment>工作区</translatorcomment>
        <translation>工作区</translation>
    </message>
</context>
</TS>

==> ukui-window-switch_4.10.1.9.orig.tar.gz: ukui-window-switch-4.10.1.9/windowsview/ukui-window-switch_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN" sourcelanguage="en_US">
<context>
    <name>DesktopArea</name>
    <message>
        <source>Desktop</source>
        <translatorcomment>工作区</translatorcomment>
        <translation type="vanished">工作区</translation>
    </message>
    <message>
        <source>New Desktop</source>
        <translatorcomment>新建工作区</translatorcomment>
        <translation type="vanished">新建工作区</translation>
    </message>
</context>
<context>
    <name>NewDesktopButton</name>
    <message>
        <location filename="qml/NewDesktopButton.qml" line="104"/>
        <source>New Desktop</source>
        <translation type="unfinished">新建工作区</translation>
    </message>
</context>
<context>
    <name>TabletViewClearAllWindowButton</name>
    <message>
        <source>Clear</source>
        <translatorcomment>清除</translatorcomment>
        <translation type="vanished">清除</translation>
    </message>
</context>
<context>
    <name>TabletViewMain</name>
    <message>
        <location filename="qml/TabletViewMain.qml" line="174"/>
        <source>No recent tasks</source>
        <translation type="unfinished">无应用开启</translation>
    </message>
    <message>
        <location filename="qml/TabletViewMain.qml" line="357"/>
        <source>Clear</source>
        <translation type="unfinished">清除</translation>
    </message>
</context>
<context>
    <name>TabletViewRootWindow</name>
    <message>
        <source>No recent tasks</source>
        <translatorcomment>无应用开启</translatorcomment>
        <translation type="vanished">无应用开启</translation>
    </message>
</context>
<context>
    <name>VirtualDesktopWindow</name>
    <message>
        <location filename="qml/VirtualDesktopWindow.qml" line="187"/>
        <source>Desktop</source>
        <translation type="unfinished">工作区</translation>
    </message>
</context>
</TS>
